==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/SharedObjectContainer.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test {

   public class SharedObjectContainer {
      
      public SharedObjectContainer() : base() {
      }
      internal String name;
      
      public void storeOne() {
         name = "hi";
      }
      
      public void testOne() {
         if (!Tester.isClientServer()) {
            for (int i1 = 0; i1 < 30; i1++) {
               ObjectContainer con1 = Db4o.openFile(Tester.FILE_SOLO);
               Object obj1 = con1.get(new SharedObjectContainer()).next();
               Tester.ensure(obj1 == this);
               con1.close();
            }
            Tester.ensure(!Tester.objectContainer().ext().isClosed());
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/SharedObjectContainer.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test {

   public class SharedObjectContainer {
      
      public SharedObjectContainer() : base() {
      }
      internal String name;
      
      public void StoreOne() {
         name = "hi";
      }
      
      public void TestOne() {
         if (!Tester.IsClientServer()) {
            for (int i1 = 0; i1 < 30; i1++) {
               ObjectContainer con1 = Db4o.OpenFile(Tester.FILE_SOLO);
               Object obj1 = con1.Get(new SharedObjectContainer()).Next();
               Tester.Ensure(obj1 == this);
               con1.Close();
            }
            Tester.Ensure(!Tester.ObjectContainer().Ext().IsClosed());
         }
      }
   }
}
